@@ -19,7 +19,7 @@ class CalibrateAZFP(CalibrateBase):
         self.get_cal_params(cal_params)
 
         # self.range_meter computed under self._cal_power()
-        # because the implementation is different for Sv and Sp
+        # because the implementation is different for Sv and TS
 
     def get_cal_params(self, cal_params):
         """Get cal params using user inputs or values from data file.
@@ -28,12 +28,18 @@ class CalibrateAZFP(CalibrateBase):
         ----------
         cal_params : dict
         """
-        # Params from the Beam group
-        for p in ["EL", "DS", "TVR", "VTX", "Sv_offset", "equivalent_beam_angle"]:
+
+        # Get params from Beam_group1
+        self.cal_params["equivalent_beam_angle"] = (
+            cal_params["equivalent_beam_angle"]
+            if "equivalent_beam_angle" in cal_params
+            else self.echodata.beam["equivalent_beam_angle"]
+        )
+
+        # Get params from the Vendor_specific group
+        for p in ["EL", "DS", "TVR", "VTX", "Sv_offset"]:
             # substitute if None in user input
-            self.cal_params[p] = (
-                cal_params[p] if p in cal_params else self.echodata.beam[p]
-            )
+            self.cal_params[p] = cal_params[p] if p in cal_params else self.echodata.vendor[p]
 
     def get_env_params(self):
         """Get env params using user inputs or values from data file.
@@ -43,17 +49,17 @@ class CalibrateAZFP(CalibrateBase):
         env_params : dict
         """
         # Temperature comes from either user input or data file
+        # Below, renaming time1 to ping_time is necessary because we are performing
+        # calculations with the beam groups that use ping_time
         self.env_params["temperature"] = (
             self.env_params["temperature"]
             if "temperature" in self.env_params
-            else self.echodata.environment["temperature"]
+            else self.echodata.environment["temperature"].rename({"time1": "ping_time"})
         )
 
         # Salinity and pressure always come from user input
         if ("salinity" not in self.env_params) or ("pressure" not in self.env_params):
-            raise ReferenceError(
-                "Please supply both salinity and pressure in env_params."
-            )
+            raise ReferenceError("Please supply both salinity and pressure in env_params.")
         else:
             self.env_params["salinity"] = self.env_params["salinity"]
             self.env_params["pressure"] = self.env_params["pressure"]
@@ -66,7 +72,7 @@ class CalibrateAZFP(CalibrateBase):
             formula_source="AZFP",
         )
         self.env_params["sound_absorption"] = uwa.calc_absorption(
-            frequency=self.echodata.beam["frequency"],
+            frequency=self.echodata.beam["frequency_nominal"],
             temperature=self.env_params["temperature"],
             salinity=self.env_params["salinity"],
             pressure=self.env_params["pressure"],
@@ -74,19 +80,17 @@ class CalibrateAZFP(CalibrateBase):
         )
 
     def compute_range_meter(self, cal_type):
-        """Calculate range in meter using AZFP formula.
+        """Calculate range (``echo_range``) in meter using AZFP formula.
 
-        Note the range calculation differs for Sv and Sp per AZFP matlab code.
+        Note the range calculation differs for Sv and TS per AZFP matlab code.
 
         Parameters
         ----------
         cal_type : str
             'Sv' for calculating volume backscattering strength, or
-            'Sp' for calculating point backscattering strength
+            'TS' for calculating target strength
         """
-        self.range_meter = self.echodata.compute_range(
-            self.env_params, azfp_cal_type=cal_type
-        )
+        self.range_meter = self.echodata.compute_range(self.env_params, azfp_cal_type=cal_type)
 
     def _cal_power(self, cal_type, **kwargs):
         """Calibrate to get volume backscattering strength (Sv) from AZFP power data.
@@ -100,7 +104,7 @@ class CalibrateAZFP(CalibrateBase):
         # Compute range in meters
         self.compute_range_meter(
             cal_type=cal_type
-        )  # range computation different for Sv and Sp per AZFP matlab code
+        )  # range computation different for Sv and TS per AZFP matlab code
 
         # Compute various params
 
@@ -112,10 +116,8 @@ class CalibrateAZFP(CalibrateBase):
         # scaling factor (slope) in Fig.G-1, units Volts/dB], see p.84
         a = self.cal_params["DS"]
         EL = (
-            self.cal_params["EL"]
-            - 2.5 / a
-            + self.echodata.beam.backscatter_r / (26214 * a)
-        )  # eq.(5)
+            self.cal_params["EL"] - 2.5 / a + self.echodata.beam.backscatter_r / (26214 * a)
+        )  # eq.(5)  # has beam dim due to backscatter_r
 
         if cal_type == "Sv":
             # eq.(9)
@@ -135,10 +137,10 @@ class CalibrateAZFP(CalibrateBase):
             )  # see p.90-91 for this correction to Sv
             out.name = "Sv"
 
-        elif cal_type == "Sp":
+        elif cal_type == "TS":
             # eq.(10)
             out = EL - SL + 2 * spreading_loss + absorption_loss
-            out.name = "Sp"
+            out.name = "TS"
         else:
             raise ValueError("cal_type not recognized!")
 
@@ -146,13 +148,18 @@ class CalibrateAZFP(CalibrateBase):
         out = out.to_dataset()
         out = out.merge(self.range_meter)
 
+        # Add frequency_nominal to data set
+        out["frequency_nominal"] = self.echodata.beam["frequency_nominal"]
+
         # Add env and cal parameters
         out = self._add_params_to_output(out)
 
-        return out
+        # Squeeze out the beam dim
+        # doing it here because both out and self.cal_params["equivalent_beam_angle"] has beam dim
+        return out.squeeze("beam", drop=True)
 
     def compute_Sv(self, **kwargs):
         return self._cal_power(cal_type="Sv")
 
-    def compute_Sp(self, **kwargs):
-        return self._cal_power(cal_type="Sp")
+    def compute_TS(self, **kwargs):
+        return self._cal_power(cal_type="TS")
