@@ -1,6 +1,5 @@
 import numpy as np
 import xarray as xr
-from dask.array.core import Array
 from scipy import signal
 
 from ..utils import uwa
@@ -47,15 +46,13 @@ class CalibrateEK(CalibrateBase):
         )
 
     def _get_vend_cal_params_power(self, param, waveform_mode):
-        """Get cal parameters stored in the Vendor group.
+        """Get cal parameters stored in the Vendor_specific group.
 
         Parameters
         ----------
-        param : str
+        param : str {"sa_correction", "gain_correction"}
             name of parameter to retrieve
         """
-        # TODO: need to test with EK80 power/angle data
-        #  currently this has only been tested with EK60 data
         ds_vend = self.echodata.vendor
 
         if ds_vend is None or param not in ds_vend:
@@ -64,48 +61,37 @@ class CalibrateEK(CalibrateBase):
         if param not in ["sa_correction", "gain_correction"]:
             raise ValueError(f"Unknown parameter {param}")
 
-        # Drop NaN ping_time for transmit_duration_nominal
-        if np.any(np.isnan(self.echodata.beam["transmit_duration_nominal"])):
-            # TODO: resolve performance warning:
-            #  /Users/wu-jung/miniconda3/envs/echopype_jan2021/lib/python3.8/site-packages/xarray/core/indexing.py:1369:
-            #  PerformanceWarning: Slicing is producing a large chunk. To accept the large
-            #  chunk and silence this warning, set the option
-            #      >>> with dask.config.set(**{'array.slicing.split_large_chunks': False}):
-            #      ...     array[indexer]
-            #  To avoid creating the large chunks, set the option
-            #      >>> with dask.config.set(**{'array.slicing.split_large_chunks': True}):
-            #      ...     array[indexer]
-            #    return self.array[key]
-            self.echodata.beam = self.echodata.beam.dropna(
-                dim="ping_time", how="any", subset=["transmit_duration_nominal"]
-            )
-
         if waveform_mode == "CW" and self.echodata.beam_power is not None:
             beam = self.echodata.beam_power
         else:
             beam = self.echodata.beam
 
         # indexes of frequencies that are for power, not complex
-        relevant_indexes = np.where(np.isin(ds_vend["frequency"], beam["frequency"]))[0]
+        relevant_indexes = np.where(
+            np.isin(ds_vend["frequency_nominal"], beam["frequency_nominal"])
+        )[0]
 
-        unique_pulse_length = np.unique(beam["transmit_duration_nominal"], axis=1)
+        # Find idx to select the corresponding param value
+        # by matching beam["transmit_duration_nominal"] with ds_vend["pulse_length"]
+        transmit_isnull = beam["transmit_duration_nominal"].isnull()
+        idxmin = np.abs(
+            beam["transmit_duration_nominal"] - ds_vend["pulse_length"][relevant_indexes]
+        ).idxmin(dim="pulse_length_bin")
 
-        pulse_length = ds_vend["pulse_length"][relevant_indexes]
+        # fill nan position with 0 (witll remove before return)
+        # and convert to int for indexing
+        idxmin = idxmin.where(~transmit_isnull, 0).astype(int)
 
-        # Find index with correct pulse length
-        idx_wanted = np.abs(pulse_length - unique_pulse_length).argmin(
-            dim="pulse_length_bin"
+        # Get param dataarray into correct shape
+        da_param = (
+            ds_vend[param][relevant_indexes]
+            .expand_dims(dim={"ping_time": idxmin["ping_time"]})  # expand dims for direct indexing
+            .sortby(idxmin.channel)  # sortby in case channel sequence different in vendor and beam
         )
 
-        # Checks for dask array and compute first
-        if isinstance(idx_wanted.data, Array):
-            idx_wanted = idx_wanted.data.compute()
-
-        return (
-            ds_vend[param]
-            .isel(pulse_length_bin=idx_wanted, frequency=relevant_indexes)
-            .drop("pulse_length_bin")
-        )
+        # Select corresponding index and clean up the original nan elements
+        da_param = da_param.isel(pulse_length_bin=idxmin, drop=True)
+        return da_param.where(~transmit_isnull, np.nan)  # set the nan elements back to nan
 
     def get_cal_params(self, cal_params, waveform_mode, encode_mode):
         """Get cal params using user inputs or values from data file.
@@ -124,11 +110,10 @@ class CalibrateEK(CalibrateBase):
         else:
             beam = self.echodata.beam
 
-        # Params from the Vendor group
+        # Params from the Vendor_specific group
+
         # only execute this if cw and power
-        if waveform_mode == "CW" and (
-            self.echodata.beam_power is not None or "quadrant" not in self.echodata.beam
-        ):
+        if waveform_mode == "CW" and beam is not None:
             params_from_vend = ["sa_correction", "gain_correction"]
             for p in params_from_vend:
                 # substitute if None in user input
@@ -152,7 +137,7 @@ class CalibrateEK(CalibrateBase):
         ----------
         cal_type : str
             'Sv' for calculating volume backscattering strength, or
-            'Sp' for calculating point backscattering strength
+            'TS' for calculating target strength
         use_beam_power : bool
             whether to use beam_power.
             If ``True`` use ``echodata.beam_power``; if ``False`` use ``echodata.beam``.
@@ -161,7 +146,7 @@ class CalibrateEK(CalibrateBase):
         Returns
         -------
         xr.Dataset
-            The calibrated dataset containing Sv or Sp
+            The calibrated dataset containing Sv or TS
         """
         # Select source of backscatter data
         if use_beam_power:
@@ -170,7 +155,7 @@ class CalibrateEK(CalibrateBase):
             beam = self.echodata.beam
 
         # Derived params
-        wavelength = self.env_params["sound_speed"] / beam["frequency"]  # wavelength
+        wavelength = self.env_params["sound_speed"] / beam["frequency_nominal"]  # wavelength
         range_meter = self.range_meter
 
         # Transmission loss
@@ -182,7 +167,7 @@ class CalibrateEK(CalibrateBase):
             CSv = (
                 10 * np.log10(beam["transmit_power"])
                 + 2 * self.cal_params["gain_correction"]
-                + self.cal_params["equivalent_beam_angle"]
+                + self.cal_params["equivalent_beam_angle"]  # has beam dim
                 + 10
                 * np.log10(
                     wavelength**2
@@ -194,15 +179,15 @@ class CalibrateEK(CalibrateBase):
 
             # Calibration and echo integration
             out = (
-                beam["backscatter_r"]
+                beam["backscatter_r"]  # has beam dim
                 + spreading_loss
                 + absorption_loss
-                - CSv
+                - CSv  # has beam dim
                 - 2 * self.cal_params["sa_correction"]
             )
             out.name = "Sv"
 
-        elif cal_type == "Sp":
+        elif cal_type == "TS":
             # Calc gain
             CSp = (
                 10 * np.log10(beam["transmit_power"])
@@ -212,16 +197,21 @@ class CalibrateEK(CalibrateBase):
 
             # Calibration and echo integration
             out = beam["backscatter_r"] + spreading_loss * 2 + absorption_loss - CSp
-            out.name = "Sp"
+            out.name = "TS"
 
         # Attach calculated range (with units meter) into data set
         out = out.to_dataset()
         out = out.merge(range_meter)
 
+        # Add frequency_nominal to data set
+        out["frequency_nominal"] = beam["frequency_nominal"]
+
         # Add env and cal parameters
         out = self._add_params_to_output(out)
 
-        return out
+        # Squeeze out the beam dim
+        # doing it here because both out and self.cal_params["equivalent_beam_angle"] has beam dim
+        return out.squeeze("beam", drop=True)
 
 
 class CalibrateEK60(CalibrateEK):
@@ -260,29 +250,36 @@ class CalibrateEK60(CalibrateEK):
                 pressure=self.env_params["pressure"],
             )
             self.env_params["sound_absorption"] = uwa.calc_absorption(
-                frequency=self.echodata.beam["frequency"],
+                frequency=self.echodata.beam["frequency_nominal"],
                 temperature=self.env_params["temperature"],
                 salinity=self.env_params["salinity"],
                 pressure=self.env_params["pressure"],
             )
         # Otherwise get sound speed and absorption from user inputs or raw data file
         else:
+            # Below, renaming time1 to ping_time is necessary because
+            # we are performing calculations with the beam groups that use ping_time
+
             self.env_params["sound_speed"] = (
                 self.env_params["sound_speed"]
                 if "sound_speed" in self.env_params
-                else self.echodata.environment["sound_speed_indicative"]
+                else self.echodata.environment["sound_speed_indicative"].rename(
+                    {"time1": "ping_time"}
+                )
             )
             self.env_params["sound_absorption"] = (
                 self.env_params["sound_absorption"]
                 if "sound_absorption" in self.env_params
-                else self.echodata.environment["absorption_indicative"]
+                else self.echodata.environment["absorption_indicative"].rename(
+                    {"time1": "ping_time"}
+                )
             )
 
     def compute_Sv(self, **kwargs):
         return self._cal_power(cal_type="Sv")
 
-    def compute_Sp(self, **kwargs):
-        return self._cal_power(cal_type="Sp")
+    def compute_TS(self, **kwargs):
+        return self._cal_power(cal_type="TS")
 
 
 class CalibrateEK80(CalibrateEK):
@@ -303,9 +300,7 @@ class CalibrateEK80(CalibrateEK):
         self.get_env_params(waveform_mode=waveform_mode, encode_mode=encode_mode)
         if cal_params is None:
             cal_params = {}
-        self.get_cal_params(
-            cal_params, waveform_mode=waveform_mode, encode_mode=encode_mode
-        )
+        self.get_cal_params(cal_params, waveform_mode=waveform_mode, encode_mode=encode_mode)
 
         # self.range_meter computed under self._compute_cal()
         # because the implementation is different depending on waveform_mode and encode_mode
@@ -351,7 +346,7 @@ class CalibrateEK80(CalibrateEK):
         if waveform_mode == "BB":
             freq = (beam["frequency_start"] + beam["frequency_end"]) / 2
         else:
-            freq = beam["frequency"]
+            freq = beam["frequency_nominal"]
 
         # Re-calculate environment parameters if user supply all env variables
         if (
@@ -375,6 +370,9 @@ class CalibrateEK80(CalibrateEK):
         #  get sound speed from user inputs or raw data file
         #  get absorption from user inputs or computing from env params stored in raw data file
         else:
+            # Below, renaming time1 to ping_time is necessary because
+            # we are performing calculations with the beam groups that use ping_time
+
             # pressure is encoded as "depth" in EK80  # TODO: change depth to pressure in EK80 file?
             for p1, p2 in zip(
                 ["temperature", "salinity", "pressure"],
@@ -383,12 +381,14 @@ class CalibrateEK80(CalibrateEK):
                 self.env_params[p1] = (
                     self.env_params[p1]
                     if p1 in self.env_params
-                    else self.echodata.environment[p2]
+                    else self.echodata.environment[p2].rename({"time1": "ping_time"})
                 )
             self.env_params["sound_speed"] = (
                 self.env_params["sound_speed"]
                 if "sound_speed" in self.env_params
-                else self.echodata.environment["sound_speed_indicative"]
+                else self.echodata.environment["sound_speed_indicative"].rename(
+                    {"time1": "ping_time"}
+                )
             )
             self.env_params["sound_absorption"] = (
                 self.env_params["sound_absorption"]
@@ -402,7 +402,7 @@ class CalibrateEK80(CalibrateEK):
             )
 
     def _get_vend_cal_params_complex(self, channel_id, filter_name, param_type):
-        """Get filter coefficients stored in the Vendor group attributes.
+        """Get filter coefficients stored in the Vendor_specific group attributes.
 
         Parameters
         ----------
@@ -423,23 +423,21 @@ class CalibrateEK80(CalibrateEK):
                 v = np.expand_dims(v, axis=0)  # expand dims for convolution
             return v
         else:
-            return self.echodata.vendor.attrs[
-                "%s %s decimation" % (channel_id, filter_name)
-            ]
+            return self.echodata.vendor.attrs["%s %s decimation" % (channel_id, filter_name)]
 
     def _tapered_chirp(
         self,
         transmit_duration_nominal,
         slope,
         transmit_power,
-        frequency=None,
+        frequency_nominal=None,
         frequency_start=None,
         frequency_end=None,
     ):
         """Create a baseline chirp template."""
         if frequency_start is None and frequency_end is None:  # CW waveform
-            frequency_start = frequency
-            frequency_end = frequency
+            frequency_start = frequency_nominal
+            frequency_end = frequency_nominal
 
         t = np.arange(0, transmit_duration_nominal, 1 / self.fs)
         nwtx = int(2 * np.floor(slope * t.size))  # length of tapering window
@@ -480,9 +478,7 @@ class CalibrateEK80(CalibrateEK):
             pc_fil = [pc_fil.squeeze()]
         ytx_pc = signal.convolve(ytx_wbt_deci, pc_fil)
         ytx_pc_deci = ytx_pc[0::pc_decifac]
-        ytx_pc_deci_time = (
-            np.arange(ytx_pc_deci.size) * 1 / self.fs * wbt_decifac * pc_decifac
-        )
+        ytx_pc_deci_time = np.arange(ytx_pc_deci.size) * 1 / self.fs * wbt_decifac * pc_decifac
 
         return ytx_pc_deci, ytx_pc_deci_time
 
@@ -501,9 +497,7 @@ class CalibrateEK80(CalibrateEK):
             ``BB`` for BB-mode samples, recorded as complex samples
         """
         if waveform_mode == "BB":
-            ytxa = (
-                signal.convolve(ytx, np.flip(np.conj(ytx))) / np.linalg.norm(ytx) ** 2
-            )
+            ytxa = signal.convolve(ytx, np.flip(np.conj(ytx))) / np.linalg.norm(ytx) ** 2
             ptxa = abs(ytxa) ** 2
         elif waveform_mode == "CW":
             ptxa = np.abs(ytx) ** 2  # energy of transmit signal
@@ -530,7 +524,7 @@ class CalibrateEK80(CalibrateEK):
         y_all = {}
         y_time_all = {}
         tau_effective = {}
-        for freq in self.echodata.beam.frequency.values:
+        for chan in self.echodata.beam.channel.values:
             # TODO: currently only deal with the case with
             # a fixed tx key param values within a channel
             if waveform_mode == "BB":
@@ -546,71 +540,59 @@ class CalibrateEK80(CalibrateEK):
                     "transmit_duration_nominal",
                     "slope",
                     "transmit_power",
-                    "frequency",
+                    "frequency_nominal",
                 ]
             tx_params = {}
             for p in tx_param_names:
-                tx_params[p] = np.unique(self.echodata.beam[p].sel(frequency=freq))
+                tx_params[p] = np.unique(self.echodata.beam[p].sel(channel=chan))
                 if tx_params[p].size != 1:
                     raise TypeError("File contains changing %s!" % p)
             y_tmp, _ = self._tapered_chirp(**tx_params)
 
             # Filter and decimate chirp template
-            channel_id = str(
-                self.echodata.beam.sel(frequency=freq)["channel_id"].values
-            )
-            fs_deci = (
-                1 / self.echodata.beam.sel(frequency=freq)["sample_interval"].values
-            )
-            y_tmp, y_tmp_time = self._filter_decimate_chirp(y_tmp, channel_id)
+            fs_deci = 1 / self.echodata.beam.sel(channel=chan)["sample_interval"].values
+            y_tmp, y_tmp_time = self._filter_decimate_chirp(y_tmp, chan)
 
             # Compute effective pulse length
-            tau_effective_tmp = self._get_tau_effective(
-                y_tmp, fs_deci, waveform_mode=waveform_mode
-            )
+            tau_effective_tmp = self._get_tau_effective(y_tmp, fs_deci, waveform_mode=waveform_mode)
 
-            y_all[channel_id] = y_tmp
-            y_time_all[channel_id] = y_tmp_time
-            tau_effective[channel_id] = tau_effective_tmp
+            y_all[chan] = y_tmp
+            y_time_all[chan] = y_tmp_time
+            tau_effective[chan] = tau_effective_tmp
 
         return y_all, y_time_all, tau_effective
 
-    def compress_pulse(self, chirp, freq_BB=None):
+    def compress_pulse(self, chirp, chan_BB=None):
         """Perform pulse compression on the backscatter data.
 
         Parameters
         ----------
         chirp : dict
             transmit chirp replica indexed by channel_id
-        freq_BB : int or float
-            frequency channels that transmit in BB mode
+        chan_BB : str
+            channels that transmit in BB mode
             (since CW mode can be in mixed in complex samples too)
         """
         backscatter = self.echodata.beam["backscatter_r"].sel(
-            frequency=freq_BB
-        ) + 1j * self.echodata.beam["backscatter_i"].sel(frequency=freq_BB)
+            channel=chan_BB
+        ) + 1j * self.echodata.beam["backscatter_i"].sel(channel=chan_BB)
 
         pc_all = []
-        for freq in freq_BB:
-            backscatter_freq = (
-                backscatter.sel(frequency=freq)
-                .dropna(dim="range_bin", how="all")
-                .dropna(dim="quadrant", how="all")
+        for chan in chan_BB:
+            backscatter_chan = (
+                backscatter.sel(channel=chan)
+                .dropna(dim="range_sample", how="all")
+                .dropna(dim="beam", how="all")
                 .dropna(dim="ping_time")
             )
-            channel_id = str(
-                self.echodata.beam.sel(frequency=freq)["channel_id"].values
-            )
-            replica = xr.DataArray(np.conj(chirp[channel_id]), dims="window")
+            replica = xr.DataArray(np.conj(chirp[str(chan.values)]), dims="window")
             # Pulse compression via rolling
             pc = (
-                backscatter_freq.rolling(range_bin=replica.size)
-                .construct("window")
-                .dot(replica)
-                / np.linalg.norm(chirp[channel_id]) ** 2
+                backscatter_chan.rolling(range_sample=replica.size).construct("window").dot(replica)
+                / np.linalg.norm(chirp[str(chan.values)]) ** 2
             )
             # Expand dimension and add name to allow merge
-            pc = pc.expand_dims(dim="frequency")
+            pc = pc.expand_dims(dim="channel")
             pc.name = "pulse_compressed_output"
             pc_all.append(pc)
 
@@ -618,10 +600,10 @@ class CalibrateEK80(CalibrateEK):
 
         return pc_merge
 
-    def _get_gain_for_complex(self, waveform_mode, freq_center) -> xr.DataArray:
+    def _get_gain_for_complex(self, waveform_mode, chan_sel) -> xr.DataArray:
         """Get gain factor for calibrating complex samples.
 
-        Use values from ``gain_correction`` in the Vendor group for CW mode samples,
+        Use values from ``gain_correction`` in the Vendor_specific group for CW mode samples,
         or interpolate ``gain`` to the center frequency of each ping for BB mode samples
         if nominal frequency is within the calibrated frequencies range
 
@@ -630,9 +612,9 @@ class CalibrateEK80(CalibrateEK):
         waveform_mode : str
             ``CW`` for CW-mode samples, either recorded as complex or power samples
             ``BB`` for BB-mode samples, recorded as complex samples
-        freq_center : xr.DataArray
-            Nominal channel frequency for CW mode samples
-            and an xr.DataArray with coorindate ``frequency`` and ``ping_time`` for BB mode samples
+        chan_sel : xr.DataArray
+            Nominal channel for CW mode samples
+            and a xr.DataArray of selected channels for BB mode samples
 
         Returns
         -------
@@ -647,26 +629,23 @@ class CalibrateEK80(CalibrateEK):
                 # index using channel_id as order of frequency across channel can be arbitrary
                 # reference to freq_center in case some channels are CW complex samples
                 # (already dropped when computing freq_center in the calling function)
-                for fn in freq_center.frequency:
-                    ch_id = self.echodata.beam.channel_id.sel(frequency=fn)
-                    # if freq-dependent gain exists in data
+                for ch_id in chan_sel:
+                    # if channel gain exists in data
                     if ch_id in self.echodata.vendor.cal_channel_id:
                         gain_vec = self.echodata.vendor.gain.sel(cal_channel_id=ch_id)
                         gain_temp = (
                             gain_vec.interp(
-                                cal_frequency=freq_center.sel(frequency=fn)
+                                cal_frequency=self.echodata.vendor.frequency_nominal.sel(
+                                    channel=ch_id
+                                )
                             ).drop(["cal_channel_id", "cal_frequency"])
-                        ).expand_dims("frequency")
+                        ).expand_dims("channel")
                     # if no freq-dependent gain use CW gain
                     else:
                         gain_temp = (
-                            gain_single.sel(frequency=fn)
-                            .assign_coords(ping_time=np.datetime64(0, "ns"))
-                            .expand_dims("ping_time")
-                            .reindex_like(
-                                self.echodata.beam.backscatter_r, method="nearest"
-                            )
-                            .expand_dims("frequency")
+                            gain_single.sel(channel=ch_id)
+                            .reindex_like(self.echodata.beam.backscatter_r, method="nearest")
+                            .expand_dims("channel")
                         )
                     gain_temp.name = "gain"
                     gain.append(gain_temp)
@@ -676,7 +655,7 @@ class CalibrateEK80(CalibrateEK):
         elif waveform_mode == "CW":
             gain = self._get_vend_cal_params_power(
                 "gain_correction", waveform_mode=waveform_mode
-            ).sel(frequency=freq_center.frequency)
+            ).sel(channel=chan_sel)
 
         return gain
 
@@ -687,7 +666,7 @@ class CalibrateEK80(CalibrateEK):
         ----------
         cal_type : str
             'Sv' for calculating volume backscattering strength, or
-            'Sp' for calculating point backscattering strength
+            'TS' for calculating target strength
         waveform_mode : {"CW", "BB"}
             Type of transmit waveform.
 
@@ -699,21 +678,17 @@ class CalibrateEK80(CalibrateEK):
         Returns
         -------
         xr.Dataset
-            The calibrated dataset containing Sv or Sp
+            The calibrated dataset containing Sv or TS
         """
         # Transmit replica and effective pulse length
         chirp, _, tau_effective = self.get_transmit_chirp(waveform_mode=waveform_mode)
 
         # use center frequency for each ping to select BB or CW channels
         # when all samples are encoded as complex samples
-        if (
-            "frequency_start" in self.echodata.beam
-            and "frequency_end" in self.echodata.beam
-        ):
+        if "frequency_start" in self.echodata.beam and "frequency_end" in self.echodata.beam:
             freq_center = (
-                self.echodata.beam["frequency_start"]
-                + self.echodata.beam["frequency_end"]
-            ) / 2
+                self.echodata.beam["frequency_start"] + self.echodata.beam["frequency_end"]
+            ) / 2  # has beam dim
         else:
             freq_center = None
 
@@ -725,13 +700,13 @@ class CalibrateEK80(CalibrateEK):
                 )
             # if CW and BB complex samples co-exist
             # drop those that contain CW samples (nan in freq start/end)
-            freq_sel = freq_center.dropna(dim="frequency")
+            chan_sel = freq_center.dropna(dim="channel").channel
 
             # backscatter data
-            pc = self.compress_pulse(chirp, freq_BB=freq_sel.frequency)
+            pc = self.compress_pulse(chirp, chan_BB=chan_sel)  # has beam dim
             prx = (
-                self.echodata.beam.quadrant.size
-                * np.abs(pc.mean(dim="quadrant")) ** 2
+                self.echodata.beam.beam.size
+                * np.abs(pc.mean(dim="beam")) ** 2
                 / (2 * np.sqrt(2)) ** 2
                 * (np.abs(self.z_er + self.z_et) / self.z_er) ** 2
                 / self.z_et
@@ -739,20 +714,19 @@ class CalibrateEK80(CalibrateEK):
         else:
             if freq_center is None:
                 # when only have CW complex samples
-                freq_sel = self.echodata.beam.frequency
+                chan_sel = self.echodata.beam.channel
             else:
                 # if BB and CW complex samples co-exist
                 # drop those that contain BB samples (not nan in freq start/end)
-                freq_sel = freq_center.where(np.isnan(freq_center), drop=True).frequency
+                chan_sel = freq_center.where(np.isnan(freq_center), drop=True).channel
 
             # backscatter data
             backscatter_cw = (
-                self.echodata.beam["backscatter_r"]
-                + 1j * self.echodata.beam["backscatter_i"]
+                self.echodata.beam["backscatter_r"] + 1j * self.echodata.beam["backscatter_i"]
             )
             prx = (
-                self.echodata.beam.quadrant.size
-                * np.abs(backscatter_cw.mean(dim="quadrant")) ** 2
+                self.echodata.beam.beam.size
+                * np.abs(backscatter_cw.mean(dim="beam")) ** 2
                 / (2 * np.sqrt(2)) ** 2
                 * (np.abs(self.z_er + self.z_et) / self.z_er) ** 2
                 / self.z_et
@@ -760,104 +734,103 @@ class CalibrateEK80(CalibrateEK):
             prx.name = "received_power"
             prx = prx.to_dataset()
 
-        # derived params
-        sound_speed = self.env_params["sound_speed"].squeeze()
-        absorption = (
-            self.env_params["sound_absorption"]
-            .sel(frequency=freq_sel.frequency)
-            .squeeze()
-        )
-        range_meter = self.range_meter.sel(frequency=freq_sel.frequency).squeeze()
+        # Derived params
+        # TODO: right now squeeze out the single ping_time dimension
+        #  Need to properly align based on actual time
+        #  This ping_time is actually renamed from time1 in Environment group,
+        #  so that in the computation of range_meter it can be aligned with echo data easily.
+        #  This however makes this part of code less traceable,
+        #  since the ping_time here does not come from the "pings"
+        #  Will resolve later.
+        sound_speed = self.env_params["sound_speed"].squeeze(drop=True)
+        absorption = self.env_params["sound_absorption"].sel(channel=chan_sel).squeeze(drop=True)
+        range_meter = self.range_meter.sel(channel=chan_sel)
         if waveform_mode == "BB":
             # use true center frequency for BB pulse
-            wavelength = sound_speed / freq_sel
+            wavelength = sound_speed / self.echodata.beam.frequency_nominal.sel(channel=chan_sel)
 
             # use true center frequency to interpolate for gain factor
-            gain = self._get_gain_for_complex(
-                waveform_mode=waveform_mode, freq_center=freq_sel
-            )
+            gain = self._get_gain_for_complex(waveform_mode=waveform_mode, chan_sel=chan_sel)
 
         else:
             # use nominal channel frequency for CW pulse
-            wavelength = sound_speed / freq_sel
+            wavelength = sound_speed / self.echodata.beam.frequency_nominal.sel(channel=chan_sel)
 
             # use nominal channel frequency to select gain factor
-            gain = self._get_gain_for_complex(
-                waveform_mode=waveform_mode, freq_center=freq_sel
-            )
+            gain = self._get_gain_for_complex(waveform_mode=waveform_mode, chan_sel=chan_sel)
 
         # Transmission loss
         spreading_loss = 20 * np.log10(range_meter.where(range_meter >= 1, other=1))
         absorption_loss = 2 * absorption * range_meter
 
-        # TODO: both Sv and Sp are off by ~<0.5 dB from matlab outputs.
+        # TODO: both Sv and TS are off by ~<0.5 dB from matlab outputs.
         #  Is this due to the use of 'single' in matlab code?
         if cal_type == "Sv":
             # effective pulse length
             tau_effective = xr.DataArray(
                 data=list(tau_effective.values()),
-                coords=[self.echodata.beam.frequency, self.echodata.beam.ping_time],
-                dims=["frequency", "ping_time"],
-            ).sel(frequency=freq_sel.frequency)
+                coords=[self.echodata.beam.channel, self.echodata.beam.ping_time],
+                dims=["channel", "ping_time"],
+            ).sel(channel=chan_sel)
 
             # other params
-            transmit_power = self.echodata.beam["transmit_power"].sel(
-                frequency=freq_sel.frequency
-            )
+            transmit_power = self.echodata.beam["transmit_power"].sel(channel=chan_sel)
+            # equivalent_beam_angle has beam dim
             if waveform_mode == "BB":
                 psifc = self.echodata.beam["equivalent_beam_angle"].sel(
-                    frequency=freq_sel.frequency
-                ) + 10 * np.log10(freq_sel.frequency / freq_center)
-            elif waveform_mode == "CW":
-                psifc = self.echodata.beam["equivalent_beam_angle"].sel(
-                    frequency=freq_sel.frequency
+                    channel=chan_sel
+                ) + 10 * np.log10(
+                    self.echodata.vendor.frequency_nominal.sel(channel=chan_sel) / freq_center
                 )
+            elif waveform_mode == "CW":
+                psifc = self.echodata.beam["equivalent_beam_angle"].sel(channel=chan_sel)
 
             out = (
                 10 * np.log10(prx)
                 + spreading_loss
                 + absorption_loss
-                - 10
-                * np.log10(
-                    wavelength**2 * transmit_power * sound_speed / (32 * np.pi**2)
-                )
+                - 10 * np.log10(wavelength**2 * transmit_power * sound_speed / (32 * np.pi**2))
                 - 2 * gain
                 - 10 * np.log10(tau_effective)
                 - psifc
             )
             out = out.rename_vars({list(out.data_vars.keys())[0]: "Sv"})
 
-        elif cal_type == "Sp":
-            transmit_power = self.echodata.beam["transmit_power"].sel(
-                frequency=freq_sel.frequency
-            )
+        elif cal_type == "TS":
+            transmit_power = self.echodata.beam["transmit_power"].sel(channel=chan_sel)
 
             out = (
                 10 * np.log10(prx)
                 + 2 * spreading_loss
-                + absorption_loss
+                + absorption_loss  # has beam dim
                 - 10 * np.log10(wavelength**2 * transmit_power / (16 * np.pi**2))
                 - 2 * gain
             )
-            out = out.rename_vars({list(out.data_vars.keys())[0]: "Sp"})
+            out = out.rename_vars({list(out.data_vars.keys())[0]: "TS"})
 
         # Attach calculated range (with units meter) into data set
         out = out.merge(range_meter)
 
+        # Add frequency_nominal to data set
+        out["frequency_nominal"] = self.echodata.beam["frequency_nominal"]
+
         # Add env and cal parameters
         out = self._add_params_to_output(out)
 
-        return out
+        # Squeeze out the beam dim
+        # out has beam dim, which came from absorption and absorption_loss
+        # self.cal_params["equivalent_beam_angle"] also has beam dim
+        return out.isel(beam=0).drop("beam")
 
     def _compute_cal(self, cal_type, waveform_mode, encode_mode) -> xr.Dataset:
         """
-        Private method to compute Sv or Sp from EK80 data, called by compute_Sv or compute_Sp.
+        Private method to compute Sv or TS from EK80 data, called by compute_Sv or compute_TS.
 
         Parameters
         ----------
         cal_type : str
             'Sv' for calculating volume backscattering strength, or
-            'Sp' for calculating point backscattering strength
+            'TS' for calculating target strength
 
         waveform_mode : {"CW", "BB"}
             Type of transmit waveform.
@@ -877,7 +850,7 @@ class CalibrateEK80(CalibrateEK):
         Returns
         -------
         xr.Dataset
-            An xarray Dataset containing either Sv or Sp.
+            An xarray Dataset containing either Sv or TS.
         """
         # Raise error for wrong inputs
         if waveform_mode not in ("BB", "CW"):
@@ -897,9 +870,7 @@ class CalibrateEK80(CalibrateEK):
         # BB: complex only, CW: complex or power
         if waveform_mode == "BB":
             if encode_mode == "power":  # BB waveform forces to collect complex samples
-                raise ValueError(
-                    "encode_mode='power' not allowed when waveform_mode='BB'!"
-                )
+                raise ValueError("encode_mode='power' not allowed when waveform_mode='BB'!")
             flag_complex = True
         else:  # waveform_mode="CW"
             if encode_mode == "complex":
@@ -941,9 +912,7 @@ class CalibrateEK80(CalibrateEK):
                     "Only complex samples are calibrated, but power samples also exist in the raw data file!"  # noqa
                 )
         else:  # only power OR complex samples exist
-            if (
-                "quadrant" in self.echodata.beam.dims
-            ):  # data contain only complex samples
+            if "backscatter_i" in self.echodata.beam.variables:  # data contain only complex samples
                 if encode_mode == "power":
                     raise TypeError(
                         "File does not contain power samples! Use encode_mode='complex'"
@@ -957,9 +926,7 @@ class CalibrateEK80(CalibrateEK):
         # Compute Sv
         if flag_complex:
             # Complex samples can be BB or CW
-            self.compute_range_meter(
-                waveform_mode=waveform_mode, encode_mode=encode_mode
-            )
+            self.compute_range_meter(waveform_mode=waveform_mode, encode_mode=encode_mode)
             ds_cal = self._cal_complex(cal_type=cal_type, waveform_mode=waveform_mode)
         else:
             # Power samples only make sense for CW mode data
@@ -992,14 +959,14 @@ class CalibrateEK80(CalibrateEK):
         -------
         Sv : xr.DataSet
             A DataSet containing volume backscattering strength (``Sv``)
-            and the corresponding range (``range``) in units meter.
+            and the corresponding range (``echo_range``) in units meter.
         """
         return self._compute_cal(
             cal_type="Sv", waveform_mode=waveform_mode, encode_mode=encode_mode
         )
 
-    def compute_Sp(self, waveform_mode="BB", encode_mode="complex"):
-        """Compute point backscattering strength (Sp).
+    def compute_TS(self, waveform_mode="BB", encode_mode="complex"):
+        """Compute target strength (TS).
 
         Parameters
         ----------
@@ -1020,10 +987,10 @@ class CalibrateEK80(CalibrateEK):
 
         Returns
         -------
-        Sp : xr.DataSet
-            A DataSet containing point backscattering strength (``Sp``)
-            and the corresponding range (``range``) in units meter.
+        TS : xr.DataSet
+            A DataSet containing target strength (``TS``)
+            and the corresponding range (``echo_range``) in units meter.
         """
         return self._compute_cal(
-            cal_type="Sp", waveform_mode=waveform_mode, encode_mode=encode_mode
+            cal_type="TS", waveform_mode=waveform_mode, encode_mode=encode_mode
         )
