@@ -23,6 +23,18 @@ def merge_attrs(datasets: List[xr.Dataset]) -> List[xr.Dataset]:
 
 
 class SetGroupsAd2cp(SetGroupsBase):
+    """Class for saving groups to netcdf or zarr from Ad2cp data files."""
+
+    beamgroups_possible = [
+        {
+            "name": "Beam_group1",
+            "descr": (
+                "contains velocity, correlation, and backscatter power (uncalibrated)"
+                " data and other data derived from acoustic data."
+            ),
+        }
+    ]
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.pulse_compressed = self.parser_obj.get_pulse_compressed()
@@ -37,9 +49,7 @@ class SetGroupsAd2cp(SetGroupsBase):
         max_samples = 0
         for packet in self.parser_obj.echosounder_raw_packets:
             # both _r and _i have same dimensions
-            max_samples = max(
-                max_samples, packet.data["echosounder_raw_samples_i"].shape[0]
-            )
+            max_samples = max(max_samples, packet.data["echosounder_raw_samples_i"].shape[0])
         for packet in self.parser_obj.echosounder_raw_packets:
             packet.data["echosounder_raw_samples_i"] = np.pad(
                 packet.data["echosounder_raw_samples_i"],
@@ -100,9 +110,7 @@ class SetGroupsAd2cp(SetGroupsBase):
             else:
                 return None
 
-        burst_ds = make_dataset(
-            self.parser_obj.burst_packets, ping_time_dim="ping_time_burst"
-        )
+        burst_ds = make_dataset(self.parser_obj.burst_packets, ping_time_dim="ping_time_burst")
         average_ds = make_dataset(
             self.parser_obj.average_packets, ping_time_dim="ping_time_average"
         )
@@ -177,9 +185,9 @@ class SetGroupsAd2cp(SetGroupsBase):
                 "ping_time_average": self.ds.get("ping_time_average"),
                 "ping_time_echosounder": self.ds.get("ping_time_echosounder"),
                 "beam": self.ds.get("beam"),
-                "range_bin_burst": self.ds.get("range_bin_burst"),
-                "range_bin_average": self.ds.get("range_bin_average"),
-                "range_bin_echosounder": self.ds.get("range_bin_echosounder"),
+                "range_sample_burst": self.ds.get("range_sample_burst"),
+                "range_sample_average": self.ds.get("range_sample_average"),
+                "range_sample_echosounder": self.ds.get("range_sample_echosounder"),
             },
             attrs={
                 "platform_name": self.ui_param["platform_name"],
@@ -191,8 +199,8 @@ class SetGroupsAd2cp(SetGroupsBase):
 
     def set_beam(self) -> xr.Dataset:
         # TODO: should we divide beam into burst/average (e.g., beam_burst, beam_average)
-        # like was done for range_bin (we have range_bin_burst, range_bin_average,
-        # and range_bin_echosounder)?
+        # like was done for range_sample (we have range_sample_burst, range_sample_average,
+        # and range_sample_echosounder)?
         data_vars = {
             "number_of_beams": self.ds.get("num_beams"),
             "coordinate_system": self.ds.get("coordinate_system"),
@@ -224,12 +232,8 @@ class SetGroupsAd2cp(SetGroupsBase):
             "ast_offset_100us": self.ds.get("ast_offset_100us"),
             "ast_pressure": self.ds.get("ast_pressure"),
             "altimeter_spare": self.ds.get("altimeter_spare"),
-            "altimeter_raw_data_num_samples": self.ds.get(
-                "altimeter_raw_data_num_samples"
-            ),
-            "altimeter_raw_data_sample_distance": self.ds.get(
-                "altimeter_raw_data_sample_distance"
-            ),
+            "altimeter_raw_data_num_samples": self.ds.get("altimeter_raw_data_num_samples"),
+            "altimeter_raw_data_sample_distance": self.ds.get("altimeter_raw_data_sample_distance"),
             "altimeter_raw_data_samples": self.ds.get("altimeter_raw_data_samples"),
         }
 
@@ -241,9 +245,9 @@ class SetGroupsAd2cp(SetGroupsBase):
                 "ping_time_average": self.ds.get("ping_time_average"),
                 "ping_time_echosounder": self.ds.get("ping_time_echosounder"),
                 "beam": self.ds.get("beam"),
-                "range_bin_burst": self.ds.get("range_bin_burst"),
-                "range_bin_average": self.ds.get("range_bin_average"),
-                "range_bin_echosounder": self.ds.get("range_bin_echosounder"),
+                "range_sample_burst": self.ds.get("range_sample_burst"),
+                "range_sample_average": self.ds.get("range_sample_average"),
+                "range_sample_echosounder": self.ds.get("range_sample_echosounder"),
                 "altimeter_sample_bin": self.ds.get("altimeter_sample_bin"),
             },
             attrs={"pulse_compressed": self.pulse_compressed},
@@ -278,19 +282,13 @@ class SetGroupsAd2cp(SetGroupsBase):
                 "status0": self.ds.get("status0"),
                 "battery_voltage": self.ds.get("battery_voltage"),
                 "power_level": self.ds.get("power_level"),
-                "temperature_of_pressure_sensor": self.ds.get(
-                    "temperature_from_pressure_sensor"
-                ),
+                "temperature_of_pressure_sensor": self.ds.get("temperature_from_pressure_sensor"),
                 "nominal_correlation": self.ds.get("nominal_correlation"),
                 "magnetometer_temperature": self.ds.get("magnetometer_temperature"),
-                "real_ping_time_clock_temperature": self.ds.get(
-                    "real_ping_time_clock_temperature"
-                ),
+                "real_ping_time_clock_temperature": self.ds.get("real_ping_time_clock_temperature"),
                 "ensemble_counter": self.ds.get("ensemble_counter"),
                 "ahrs_rotation_matrix_mij": (
-                    ("mij", "ping_time")
-                    if "ahrs_rotation_matrix_m11" in self.ds
-                    else "mij",
+                    ("mij", "ping_time") if "ahrs_rotation_matrix_m11" in self.ds else "mij",
                     [
                         self.ds.get("ahrs_rotation_matrix_m11"),
                         self.ds.get("ahrs_rotation_matrix_m12"),
@@ -304,9 +302,7 @@ class SetGroupsAd2cp(SetGroupsBase):
                     ],
                 ),
                 "ahrs_quaternions_wxyz": (
-                    ("wxyz", "ping_time")
-                    if "ahrs_quaternions_w" in self.ds
-                    else "wxyz",
+                    ("wxyz", "ping_time") if "ahrs_quaternions_w" in self.ds else "wxyz",
                     [
                         self.ds.get("ahrs_quaternions_w"),
                         self.ds.get("ahrs_quaternions_x"),
@@ -350,9 +346,9 @@ class SetGroupsAd2cp(SetGroupsBase):
                 "sample": self.ds.get("sample"),
                 "sample_transmit": self.ds.get("sample_transmit"),
                 "beam": self.ds.get("beam"),
-                "range_bin_average": self.ds.get("range_bin_average"),
-                "range_bin_burst": self.ds.get("range_bin_burst"),
-                "range_bin_echosounder": self.ds.get("range_bin_echosounder"),
+                "range_sample_average": self.ds.get("range_sample_average"),
+                "range_sample_burst": self.ds.get("range_sample_burst"),
+                "range_sample_echosounder": self.ds.get("range_sample_echosounder"),
             },
             attrs={**attrs, "pulse_compressed": self.pulse_compressed},
         )
@@ -374,22 +370,32 @@ class SetGroupsAd2cp(SetGroupsBase):
         return set_encodings(ds)
 
     def set_sonar(self) -> xr.Dataset:
-        ds = xr.Dataset(
-            attrs={
-                "sonar_manufacturer": "Nortek",
-                "sonar_model": "AD2CP",
-                "sonar_serial_number": "",
-                "sonar_software_name": "",
-                "sonar_software_version": "",
-                "sonar_firmware_version": "",
-                "sonar_type": "acoustic Doppler current profiler (ADCP)",
-            }
-        )
+        """Set the Sonar group."""
+
+        # Add beam_group and beam_group_descr variables sharing a common dimension
+        # (beam_group), using the information from self._beamgroups
+        self._beamgroups = self.beamgroups_possible
+        beam_groups_vars, beam_groups_coord = self._beam_groups_vars()
+        ds = xr.Dataset(beam_groups_vars, coords=beam_groups_coord)
+
+        # Assemble sonar group global attribute dictionary
+        sonar_attr_dict = {
+            "sonar_manufacturer": "Nortek",
+            "sonar_model": self.sonar_model,
+            "sonar_serial_number": "",
+            "sonar_software_name": "",
+            "sonar_software_version": "",
+            "sonar_firmware_version": "",
+            "sonar_type": "acoustic Doppler current profiler (ADCP)",
+        }
         if "serial_number" in self.ds:
-            ds.attrs["sonar_serial_number"] = int(self.ds["serial_number"].data[0])
+            sonar_attr_dict["sonar_serial_number"] = int(self.ds["serial_number"].data[0])
         firmware_version = self.parser_obj.get_firmware_version()
         if firmware_version is not None:
-            ds.attrs["sonar_firmware_version"] = ", ".join(
+            sonar_attr_dict["sonar_firmware_version"] = ", ".join(
                 [f"{k}:{v}" for k, v in firmware_version.items()]
             )
+
+        ds = ds.assign_attrs(sonar_attr_dict)
+
         return ds
