@@ -1,17 +1,11 @@
 import warnings
 from collections import defaultdict
-from datetime import datetime as dt
 
 import numpy as np
 import xarray as xr
-from _echopype_version import version as ECHOPYPE_VERSION
 
-from ..echodata.convention.attrs import (
-    DEFAULT_BEAM_COORD_ATTRS,
-    DEFAULT_PLATFORM_COORD_ATTRS,
-    DEFAULT_PLATFORM_VAR_ATTRS,
-)
 from ..utils.coding import set_encodings
+from ..utils.prov import echopype_prov_attrs, source_files_vars
 
 # fmt: off
 from .set_groups_base import DEFAULT_CHUNK_SIZE, SetGroupsBase
@@ -22,6 +16,42 @@ from .set_groups_base import DEFAULT_CHUNK_SIZE, SetGroupsBase
 class SetGroupsEK60(SetGroupsBase):
     """Class for saving groups to netcdf or zarr from EK60 data files."""
 
+    # The sets beam_only_names, ping_time_only_names, and
+    # beam_ping_time_names are used in set_groups_base and
+    # in converting from v0.5.x to v0.6.0. The values within
+    # these sets are applied to all Sonar/Beam_groupX groups.
+
+    # Variables that need only the beam dimension added to them.
+    beam_only_names = {"backscatter_r", "angle_athwartship", "angle_alongship"}
+
+    # Variables that need only the ping_time dimension added to them.
+    ping_time_only_names = {"beam_type"}
+
+    # Variables that need beam and ping_time dimensions added to them.
+    beam_ping_time_names = {
+        "beam_direction_x",
+        "beam_direction_y",
+        "beam_direction_z",
+        "beamwidth_twoway_alongship",
+        "beamwidth_twoway_athwartship",
+        "angle_offset_alongship",
+        "angle_offset_athwartship",
+        "angle_sensitivity_alongship",
+        "angle_sensitivity_athwartship",
+        "equivalent_beam_angle",
+        "gain_correction",
+    }
+
+    beamgroups_possible = [
+        {
+            "name": "Beam_group1",
+            "descr": (
+                "contains backscatter power (uncalibrated) and other beam or"
+                " channel-specific data, including split-beam angle data when they exist."
+            ),
+        }
+    ]
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -34,11 +64,8 @@ class SetGroupsEK60(SetGroupsBase):
             if duplicates.any():
                 if self.old_ping_time is None:
                     if (
-                        len({arr.shape for arr in self.parser_obj.ping_time.values()})
-                        == 1
-                        and np.unique(
-                            np.stack(self.parser_obj.ping_time.values()), axis=0
-                        ).shape[0]
+                        len({arr.shape for arr in self.parser_obj.ping_time.values()}) == 1
+                        and np.unique(np.stack(self.parser_obj.ping_time.values()), axis=0).shape[0]
                         == 1
                     ):
                         self.old_ping_time = self.parser_obj.ping_time[ch]
@@ -52,9 +79,7 @@ class SetGroupsEK60(SetGroupsBase):
                 backscatter_r = self.parser_obj.ping_data_dict["power"][ch]
                 # indexes of duplicates including the originals
                 # (if there are 2 times that are the same, both will be included)
-                (all_duplicates_idx,) = np.where(
-                    np.isin(ping_time, ping_time[duplicates][0])
-                )
+                (all_duplicates_idx,) = np.where(np.isin(ping_time, ping_time[duplicates][0]))
                 if np.array_equal(
                     backscatter_r[all_duplicates_idx[0]],
                     backscatter_r[all_duplicates_idx[1]],
@@ -69,9 +94,7 @@ class SetGroupsEK60(SetGroupsBase):
                             v[ch] = v[ch][unique_idx]
                         else:
                             v[ch] = [v[ch][i] for i in unique_idx]
-                    self.parser_obj.ping_time[ch] = self.parser_obj.ping_time[ch][
-                        unique_idx
-                    ]
+                    self.parser_obj.ping_time[ch] = self.parser_obj.ping_time[ch][unique_idx]
                 else:
                     warnings.warn(
                         "duplicate ping times detected; the duplicate times will be incremented by 1 nanosecond and remain in the ping_time coordinate. The original ping times will be preserved in the Provenance group"  # noqa
@@ -83,20 +106,18 @@ class SetGroupsEK60(SetGroupsBase):
 
     def set_provenance(self) -> xr.Dataset:
         """Set the Provenance group."""
-        # Collect variables
-        prov_dict = {
-            "conversion_software_name": "echopype",
-            "conversion_software_version": ECHOPYPE_VERSION,
-            "conversion_time": dt.utcnow().isoformat(timespec="seconds")
-            + "Z",  # use UTC time
-            "src_filenames": self.input_file,
-            "duplicate_ping_times": 1 if self.old_ping_time is not None else 0,
-        }
-        # Save
+        prov_dict = echopype_prov_attrs(process_type="conversion")
+        prov_dict["duplicate_ping_times"] = 1 if self.old_ping_time is not None else 0
+        source_files = source_files_vars(self.input_file)
         if self.old_ping_time is not None:
-            ds = xr.Dataset(data_vars={"old_ping_time": self.old_ping_time})
+            ds = xr.Dataset(
+                data_vars={
+                    "old_ping_time": self.old_ping_time,
+                    **source_files,
+                }
+            )
         else:
-            ds = xr.Dataset()
+            ds = xr.Dataset(data_vars=source_files)
         ds = ds.assign_attrs(prov_dict)
         return ds
 
@@ -104,12 +125,13 @@ class SetGroupsEK60(SetGroupsBase):
         """Set the Environment group."""
         ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
         ds_env = []
+
         # Loop over channels
         for ch in ch_ids:
             ds_tmp = xr.Dataset(
                 {
                     "absorption_indicative": (
-                        ["ping_time"],
+                        ["time1"],
                         self.parser_obj.ping_data_dict["absorption_coefficient"][ch],
                         {
                             "long_name": "Indicative acoustic absorption",
@@ -118,7 +140,7 @@ class SetGroupsEK60(SetGroupsBase):
                         },
                     ),
                     "sound_speed_indicative": (
-                        ["ping_time"],
+                        ["time1"],
                         self.parser_obj.ping_data_dict["sound_velocity"][ch],
                         {
                             "long_name": "Indicative sound speed",
@@ -129,30 +151,37 @@ class SetGroupsEK60(SetGroupsBase):
                     ),
                 },
                 coords={
-                    "ping_time": (
-                        ["ping_time"],
+                    "time1": (
+                        ["time1"],
                         self.parser_obj.ping_time[ch],
                         {
                             "axis": "T",
                             "long_name": "Timestamps for NMEA position datagrams",
                             "standard_name": "time",
+                            "comment": "Time coordinate corresponding to environmental variables.",
                         },
                     )
                 },
             )
-            # Attach frequency dimension/coordinate
+            # Attach channel dimension/coordinate
             ds_tmp = ds_tmp.expand_dims(
+                {"channel": [self.parser_obj.config_datagram["transceivers"][ch]["channel_id"]]}
+            )
+            ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
+                self._varattrs["beam_coord_default"]["channel"]
+            )
+
+            ds_tmp["frequency_nominal"] = (
+                ["channel"],
+                [self.parser_obj.config_datagram["transceivers"][ch]["frequency"]],
                 {
-                    "frequency": [
-                        self.parser_obj.config_datagram["transceivers"][ch]["frequency"]
-                    ]
-                }
-            )
-            ds_tmp["frequency"] = ds_tmp["frequency"].assign_attrs(
-                units="Hz",
-                long_name="Transducer frequency",
-                valid_min=0.0,
+                    "units": "Hz",
+                    "long_name": "Transducer frequency",
+                    "valid_min": 0.0,
+                    "standard_name": "sound_frequency",
+                },
             )
+
             ds_env.append(ds_tmp)
 
         # Merge data from all channels
@@ -162,17 +191,26 @@ class SetGroupsEK60(SetGroupsBase):
 
     def set_sonar(self) -> xr.Dataset:
         """Set the Sonar group."""
-        # Assemble sonar group dictionary
-        sonar_dict = {
+
+        # Add beam_group and beam_group_descr variables sharing a common dimension
+        # (beam_group), using the information from self._beamgroups
+        self._beamgroups = self.beamgroups_possible
+        beam_groups_vars, beam_groups_coord = self._beam_groups_vars()
+        ds = xr.Dataset(beam_groups_vars, coords=beam_groups_coord)
+
+        # Assemble sonar group global attribute dictionary
+        sonar_attr_dict = {
             "sonar_manufacturer": "Simrad",
-            "sonar_model": self.parser_obj.config_datagram["sounder_name"],
+            "sonar_model": self.sonar_model,
+            # transducer (sonar) serial number is not stored in the EK60 raw data file,
+            # so sonar_serial_number can't be populated from the raw datagrams
             "sonar_serial_number": "",
-            "sonar_software_name": "",
+            "sonar_software_name": self.parser_obj.config_datagram["sounder_name"],
             "sonar_software_version": self.parser_obj.config_datagram["version"],
             "sonar_type": "echosounder",
         }
-        ds = xr.Dataset()
-        ds = ds.assign_attrs(sonar_dict)
+        ds = ds.assign_attrs(sonar_attr_dict)
+
         return ds
 
     def set_platform(self, NMEA_only=False) -> xr.Dataset:
@@ -180,32 +218,35 @@ class SetGroupsEK60(SetGroupsBase):
 
         # Collect variables
         # Read lat/long from NMEA datagram
-        location_time, msg_type, lat, lon = self._parse_NMEA()
+        time1, msg_type, lat, lon = self._parse_NMEA()
 
         # NMEA dataset: variables filled with nan if do not exist
         ds = xr.Dataset(
             {
                 "latitude": (
-                    ["location_time"],
+                    ["time1"],
                     lat,
-                    DEFAULT_PLATFORM_VAR_ATTRS["latitude"],
+                    self._varattrs["platform_var_default"]["latitude"],
                 ),
                 "longitude": (
-                    ["location_time"],
+                    ["time1"],
                     lon,
-                    DEFAULT_PLATFORM_VAR_ATTRS["longitude"],
+                    self._varattrs["platform_var_default"]["longitude"],
                 ),
-                "sentence_type": (["location_time"], msg_type),
+                "sentence_type": (["time1"], msg_type),
             },
             coords={
-                "location_time": (
-                    ["location_time"],
-                    location_time,
-                    DEFAULT_PLATFORM_COORD_ATTRS["location_time"],
+                "time1": (
+                    ["time1"],
+                    time1,
+                    {
+                        **self._varattrs["platform_coord_default"]["time1"],
+                        "comment": "Time coordinate corresponding to NMEA position data.",
+                    },
                 )
             },
         )
-        ds = ds.chunk({"location_time": DEFAULT_CHUNK_SIZE["ping_time"]})
+        ds = ds.chunk({"time1": DEFAULT_CHUNK_SIZE["ping_time"]})
 
         if not NMEA_only:
             ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
@@ -224,36 +265,84 @@ class SetGroupsEK60(SetGroupsBase):
                 ds_tmp = xr.Dataset(
                     {
                         "pitch": (
-                            ["ping_time"],
+                            ["time2"],
                             self.parser_obj.ping_data_dict["pitch"][ch],
-                            DEFAULT_PLATFORM_VAR_ATTRS["pitch"],
+                            self._varattrs["platform_var_default"]["pitch"],
                         ),
                         "roll": (
-                            ["ping_time"],
+                            ["time2"],
                             self.parser_obj.ping_data_dict["roll"][ch],
-                            DEFAULT_PLATFORM_VAR_ATTRS["roll"],
+                            self._varattrs["platform_var_default"]["roll"],
                         ),
-                        "heave": (
-                            ["ping_time"],
+                        "vertical_offset": (
+                            ["time2"],
                             self.parser_obj.ping_data_dict["heave"][ch],
-                            DEFAULT_PLATFORM_VAR_ATTRS["heave"],
+                            self._varattrs["platform_var_default"]["vertical_offset"],
                         ),
                         "water_level": (
-                            ["ping_time"],
+                            ["time3"],
                             self.parser_obj.ping_data_dict["transducer_depth"][ch],
-                            DEFAULT_PLATFORM_VAR_ATTRS["water_level"],
+                            self._varattrs["platform_var_default"]["water_level"],
                         ),
+                        "transducer_offset_x": (
+                            [],
+                            self.parser_obj.config_datagram["transceivers"][ch].get(
+                                "pos_x", np.nan
+                            ),
+                            self._varattrs["platform_var_default"]["transducer_offset_x"],
+                        ),
+                        "transducer_offset_y": (
+                            [],
+                            self.parser_obj.config_datagram["transceivers"][ch].get(
+                                "pos_y", np.nan
+                            ),
+                            self._varattrs["platform_var_default"]["transducer_offset_y"],
+                        ),
+                        "transducer_offset_z": (
+                            [],
+                            self.parser_obj.config_datagram["transceivers"][ch].get(
+                                "pos_z", np.nan
+                            ),
+                            self._varattrs["platform_var_default"]["transducer_offset_z"],
+                        ),
+                        **{
+                            var: ([], np.nan, self._varattrs["platform_var_default"][var])
+                            for var in [
+                                "MRU_offset_x",
+                                "MRU_offset_y",
+                                "MRU_offset_z",
+                                "MRU_rotation_x",
+                                "MRU_rotation_y",
+                                "MRU_rotation_z",
+                                "position_offset_x",
+                                "position_offset_y",
+                                "position_offset_z",
+                            ]
+                        },
                     },
                     coords={
-                        "ping_time": (
-                            ["ping_time"],
+                        "time2": (
+                            ["time2"],
                             self.parser_obj.ping_time[ch],
                             {
                                 "axis": "T",
-                                "long_name": "Timestamps for position datagrams",
+                                "long_name": "Timestamps for platform motion and orientation data",
                                 "standard_name": "time",
+                                "comment": "Time coordinate corresponding to platform motion and "
+                                "orientation data.",
                             },
-                        )
+                        ),
+                        "time3": (
+                            ["time3"],
+                            self.parser_obj.ping_time[ch],
+                            {
+                                "axis": "T",
+                                "long_name": "Timestamps for platform-related sampling environment",
+                                "standard_name": "time",
+                                "comment": "Time coordinate corresponding to platform-related "
+                                "sampling environment.",
+                            },
+                        ),
                     },
                     attrs={
                         "platform_code_ICES": self.ui_param["platform_code_ICES"],
@@ -262,21 +351,25 @@ class SetGroupsEK60(SetGroupsBase):
                     },
                 )
 
-                # Attach frequency dimension/coordinate
+                # Attach channel dimension/coordinate
                 ds_tmp = ds_tmp.expand_dims(
+                    {"channel": [self.parser_obj.config_datagram["transceivers"][ch]["channel_id"]]}
+                )
+                ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
+                    self._varattrs["beam_coord_default"]["channel"]
+                )
+
+                ds_tmp["frequency_nominal"] = (
+                    ["channel"],
+                    [self.parser_obj.config_datagram["transceivers"][ch]["frequency"]],
                     {
-                        "frequency": [
-                            self.parser_obj.config_datagram["transceivers"][ch][
-                                "frequency"
-                            ]
-                        ]
-                    }
-                )
-                ds_tmp["frequency"] = ds_tmp["frequency"].assign_attrs(
-                    units="Hz",
-                    long_name="Transducer frequency",
-                    valid_min=0.0,
+                        "units": "Hz",
+                        "long_name": "Transducer frequency",
+                        "valid_min": 0.0,
+                        "standard_name": "sound_frequency",
+                    },
                 )
+
                 ds_plat.append(ds_tmp)
 
             # Merge data from all channels
@@ -288,19 +381,16 @@ class SetGroupsEK60(SetGroupsBase):
             # Merge with NMEA data
             ds = xr.merge([ds, ds_plat], combine_attrs="override")
 
-            ds = ds.chunk({"ping_time": DEFAULT_CHUNK_SIZE["ping_time"]})
+            ds = ds.chunk({"time2": DEFAULT_CHUNK_SIZE["ping_time"]})
 
         return set_encodings(ds)
 
     def set_beam(self) -> xr.Dataset:
-        """Set the Beam group."""
+        """Set the /Sonar/Beam_group1 group."""
         # Get channel keys and frequency
         ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
         freq = np.array(
-            [
-                v["frequency"]
-                for v in self.parser_obj.config_datagram["transceivers"].values()
-            ]
+            [v["frequency"] for v in self.parser_obj.config_datagram["transceivers"].values()]
         )
 
         # Channel-specific variables
@@ -326,9 +416,7 @@ class SetGroupsEK60(SetGroupsBase):
         beam_params = defaultdict()
         for param in params:
             beam_params[param] = [
-                self.parser_obj.config_datagram["transceivers"][ch_seq].get(
-                    param, np.nan
-                )
+                self.parser_obj.config_datagram["transceivers"][ch_seq].get(param, np.nan)
                 for ch_seq in ch_ids
             ]
 
@@ -340,56 +428,51 @@ class SetGroupsEK60(SetGroupsBase):
         # Assemble variables into a dataset
         ds = xr.Dataset(
             {
-                "channel_id": (["frequency"], beam_params["channel_id"]),
+                "frequency_nominal": (
+                    ["channel"],
+                    freq,
+                    {
+                        "units": "Hz",
+                        "long_name": "Transducer frequency",
+                        "valid_min": 0.0,
+                        "standard_name": "sound_frequency",
+                    },
+                ),
                 "beam_type": (
-                    "frequency",
+                    "channel",
                     beam_params["beam_type"],
                     {"long_name": "type of transducer (0-single, 1-split)"},
                 ),
-                # TODO: check EK60 data spec:
-                #  the beamwidths provided are most likely 2-way beamwidth so below needs to change
-                "beamwidth_receive_alongship": (
-                    ["frequency"],
+                "beamwidth_twoway_alongship": (
+                    ["channel"],
                     beam_params["beamwidth_alongship"],
                     {
-                        "long_name": "Half power one-way receive beam width along "
-                        "alongship axis of beam",
+                        "long_name": "Half power two-way beam width along alongship axis of beam",  # noqa
                         "units": "arc_degree",
                         "valid_range": (0.0, 360.0),
+                        "comment": (
+                            "Introduced in echopype for Simrad echosounders to avoid potential confusion with convention definitions. "  # noqa
+                            "The alongship angle corresponds to the minor angle in SONAR-netCDF4 vers 2. "  # noqa
+                            "The convention defines one-way transmit or receive beamwidth (beamwidth_receive_minor and beamwidth_transmit_minor), but Simrad echosounders record two-way beamwidth in the data."  # noqa
+                        ),
                     },
                 ),
-                "beamwidth_receive_athwartship": (
-                    ["frequency"],
+                "beamwidth_twoway_athwartship": (
+                    ["channel"],
                     beam_params["beamwidth_athwartship"],
                     {
-                        "long_name": "Half power one-way receive beam width along "
-                        "athwartship axis of beam",
-                        "units": "arc_degree",
-                        "valid_range": (0.0, 360.0),
-                    },
-                ),
-                "beamwidth_transmit_alongship": (
-                    ["frequency"],
-                    beam_params["beamwidth_alongship"],
-                    {
-                        "long_name": "Half power one-way transmit beam width along "
-                        "alongship axis of beam",
-                        "units": "arc_degree",
-                        "valid_range": (0.0, 360.0),
-                    },
-                ),
-                "beamwidth_transmit_athwartship": (
-                    ["frequency"],
-                    beam_params["beamwidth_athwartship"],
-                    {
-                        "long_name": "Half power one-way transmit beam width along "
-                        "athwartship axis of beam",
+                        "long_name": "Half power two-way beam width along athwartship axis of beam",  # noqa
                         "units": "arc_degree",
                         "valid_range": (0.0, 360.0),
+                        "comment": (
+                            "Introduced in echopype for Simrad echosounders to avoid potential confusion with convention definitions. "  # noqa
+                            "The athwartship angle corresponds to the major angle in SONAR-netCDF4 vers 2. "  # noqa
+                            "The convention defines one-way transmit or receive beamwidth (beamwidth_receive_major and beamwidth_transmit_major), but Simrad echosounders record two-way beamwidth in the data."  # noqa
+                        ),
                     },
                 ),
                 "beam_direction_x": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["dir_x"],
                     {
                         "long_name": "x-component of the vector that gives the pointing "
@@ -400,7 +483,7 @@ class SetGroupsEK60(SetGroupsBase):
                     },
                 ),
                 "beam_direction_y": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["dir_y"],
                     {
                         "long_name": "y-component of the vector that gives the pointing "
@@ -411,7 +494,7 @@ class SetGroupsEK60(SetGroupsBase):
                     },
                 ),
                 "beam_direction_z": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["dir_z"],
                     {
                         "long_name": "z-component of the vector that gives the pointing "
@@ -422,27 +505,51 @@ class SetGroupsEK60(SetGroupsBase):
                     },
                 ),
                 "angle_offset_alongship": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["angle_offset_alongship"],
-                    {"long_name": "electrical alongship angle of the transducer"},
+                    {
+                        "long_name": "electrical alongship angle offset of the transducer",
+                        "comment": (
+                            "Introduced in echopype for Simrad echosounders. "  # noqa
+                            "The alongship angle corresponds to the minor angle in SONAR-netCDF4 vers 2. "  # noqa
+                        ),
+                    },
                 ),
                 "angle_offset_athwartship": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["angle_offset_athwartship"],
-                    {"long_name": "electrical athwartship angle of the transducer"},
+                    {
+                        "long_name": "electrical athwartship angle offset of the transducer",
+                        "comment": (
+                            "Introduced in echopype for Simrad echosounders. "  # noqa
+                            "The athwartship angle corresponds to the major angle in SONAR-netCDF4 vers 2. "  # noqa
+                        ),
+                    },
                 ),
                 "angle_sensitivity_alongship": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["angle_sensitivity_alongship"],
-                    {"long_name": "alongship sensitivity of the transducer"},
+                    {
+                        "long_name": "alongship angle sensitivity of the transducer",
+                        "comment": (
+                            "Introduced in echopype for Simrad echosounders. "  # noqa
+                            "The alongship angle corresponds to the minor angle in SONAR-netCDF4 vers 2. "  # noqa
+                        ),
+                    },
                 ),
                 "angle_sensitivity_athwartship": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["angle_sensitivity_athwartship"],
-                    {"long_name": "athwartship sensitivity of the transducer"},
+                    {
+                        "long_name": "athwartship angle sensitivity of the transducer",
+                        "comment": (
+                            "Introduced in echopype for Simrad echosounders. "  # noqa
+                            "The athwartship angle corresponds to the major angle in SONAR-netCDF4 vers 2. "  # noqa
+                        ),
+                    },
                 ),
                 "equivalent_beam_angle": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["equivalent_beam_angle"],
                     {
                         "long_name": "Equivalent beam angle",
@@ -450,49 +557,22 @@ class SetGroupsEK60(SetGroupsBase):
                         "valid_range": (0.0, 4 * np.pi),
                     },
                 ),
-                "transducer_offset_x": (
-                    ["frequency"],
-                    beam_params["pos_x"],
-                    {
-                        "long_name": "x-axis distance from the platform coordinate system "
-                        "origin to the sonar transducer",
-                        "units": "m",
-                    },
-                ),
-                "transducer_offset_y": (
-                    ["frequency"],
-                    beam_params["pos_y"],
-                    {
-                        "long_name": "y-axis distance from the platform coordinate system "
-                        "origin to the sonar transducer",
-                        "units": "m",
-                    },
-                ),
-                "transducer_offset_z": (
-                    ["frequency"],
-                    beam_params["pos_z"],
-                    {
-                        "long_name": "z-axis distance from the platform coordinate system "
-                        "origin to the sonar transducer",
-                        "units": "m",
-                    },
-                ),
                 "gain_correction": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["gain"],
                     {"long_name": "Gain correction", "units": "dB"},
                 ),
                 "gpt_software_version": (
-                    ["frequency"],
+                    ["channel"],
                     beam_params["gpt_software_version"],
                 ),
             },
             coords={
-                "frequency": (
-                    ["frequency"],
-                    freq,
-                    DEFAULT_BEAM_COORD_ATTRS["frequency"],
-                )
+                "channel": (
+                    ["channel"],
+                    beam_params["channel_id"],
+                    self._varattrs["beam_coord_default"]["channel"],
+                ),
             },
             attrs={"beam_mode": "vertical", "conversion_equation_t": "type_3"},
         )
@@ -504,7 +584,7 @@ class SetGroupsEK60(SetGroupsBase):
             ds_tmp = xr.Dataset(
                 {
                     "backscatter_r": (
-                        ["ping_time", "range_bin"],
+                        ["ping_time", "range_sample"],
                         self.parser_obj.ping_data_dict["power"][ch],
                         {"long_name": "Backscatter power", "units": "dB"},
                     ),
@@ -564,21 +644,19 @@ class SetGroupsEK60(SetGroupsBase):
                     "transmit_mode": (
                         ["ping_time"],
                         self.parser_obj.ping_data_dict["transmit_mode"][ch],
-                        {
-                            "long_name": "0 = Active, 1 = Passive, 2 = Test, -1 = Unknown"
-                        },
+                        {"long_name": "0 = Active, 1 = Passive, 2 = Test, -1 = Unknown"},
                     ),
                 },
                 coords={
                     "ping_time": (
                         ["ping_time"],
                         self.parser_obj.ping_time[ch],
-                        DEFAULT_BEAM_COORD_ATTRS["ping_time"],
+                        self._varattrs["beam_coord_default"]["ping_time"],
                     ),
-                    "range_bin": (
-                        ["range_bin"],
+                    "range_sample": (
+                        ["range_sample"],
                         np.arange(data_shape[1]),
-                        DEFAULT_BEAM_COORD_ATTRS["range_bin"],
+                        self._varattrs["beam_coord_default"]["range_sample"],
                     ),
                 },
             )
@@ -592,30 +670,36 @@ class SetGroupsEK60(SetGroupsBase):
                 ds_tmp = ds_tmp.assign(
                     {
                         "angle_athwartship": (
-                            ["ping_time", "range_bin"],
+                            ["ping_time", "range_sample"],
                             self.parser_obj.ping_data_dict["angle"][ch][:, :, 0],
-                            {"long_name": "electrical athwartship angle"},
+                            {
+                                "long_name": "electrical athwartship angle",
+                                "comment": (
+                                    "Introduced in echopype for Simrad echosounders. "  # noqa
+                                    + "The athwartship angle corresponds to the major angle in SONAR-netCDF4 vers 2. "  # noqa
+                                ),
+                            },
                         ),
                         "angle_alongship": (
-                            ["ping_time", "range_bin"],
+                            ["ping_time", "range_sample"],
                             self.parser_obj.ping_data_dict["angle"][ch][:, :, 1],
-                            {"long_name": "electrical alongship angle"},
+                            {
+                                "long_name": "electrical alongship angle",
+                                "comment": (
+                                    "Introduced in echopype for Simrad echosounders. "  # noqa
+                                    + "The alongship angle corresponds to the minor angle in SONAR-netCDF4 vers 2. "  # noqa
+                                ),
+                            },
                         ),
                     }
                 )
 
             # Attach frequency dimension/coordinate
             ds_tmp = ds_tmp.expand_dims(
-                {
-                    "frequency": [
-                        self.parser_obj.config_datagram["transceivers"][ch]["frequency"]
-                    ]
-                }
+                {"channel": [self.parser_obj.config_datagram["transceivers"][ch]["channel_id"]]}
             )
-            ds_tmp["frequency"] = ds_tmp["frequency"].assign_attrs(
-                units="Hz",
-                long_name="Transducer frequency",
-                valid_min=0.0,
+            ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
+                self._varattrs["beam_coord_default"]["channel"]
             )
             ds_backscatter.append(ds_tmp)
 
@@ -624,32 +708,44 @@ class SetGroupsEK60(SetGroupsBase):
             [ds, xr.merge(ds_backscatter)], combine_attrs="override"
         )  # override keeps the Dataset attributes
 
+        # Manipulate some Dataset dimensions to adhere to convention
+        self.beam_groups_to_convention(
+            ds, self.beam_only_names, self.beam_ping_time_names, self.ping_time_only_names
+        )
+
         return set_encodings(ds)
 
     def set_vendor(self) -> xr.Dataset:
         # Retrieve pulse length and sa correction
         config = self.parser_obj.config_datagram["transceivers"]
         freq = [v["frequency"] for v in config.values()]
+        ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
+        channel = [
+            self.parser_obj.config_datagram["transceivers"][ch_seq].get("channel_id", np.nan)
+            for ch_seq in ch_ids
+        ]
         pulse_length = np.array([v["pulse_length_table"] for v in config.values()])
         gain = np.array([v["gain_table"] for v in config.values()])
         sa_correction = [v["sa_correction_table"] for v in config.values()]
         # Save pulse length and sa correction
         ds = xr.Dataset(
             {
-                "sa_correction": (["frequency", "pulse_length_bin"], sa_correction),
-                "gain_correction": (["frequency", "pulse_length_bin"], gain),
-                "pulse_length": (["frequency", "pulse_length_bin"], pulse_length),
-            },
-            coords={
-                "frequency": (
-                    ["frequency"],
+                "frequency_nominal": (
+                    ["channel"],
                     freq,
                     {
                         "units": "Hz",
                         "long_name": "Transducer frequency",
                         "valid_min": 0.0,
+                        "standard_name": "sound_frequency",
                     },
                 ),
+                "sa_correction": (["channel", "pulse_length_bin"], sa_correction),
+                "gain_correction": (["channel", "pulse_length_bin"], gain),
+                "pulse_length": (["channel", "pulse_length_bin"], pulse_length),
+            },
+            coords={
+                "channel": (["channel"], channel, self._varattrs["beam_coord_default"]["channel"]),
                 "pulse_length_bin": (
                     ["pulse_length_bin"],
                     np.arange(pulse_length.shape[1]),
