@@ -1,16 +1,13 @@
 import warnings
 import matplotlib.pyplot as plt
 import matplotlib.cm
-import math
 import xarray as xr
 import numpy as np
 from xarray.plot.facetgrid import FacetGrid
 from matplotlib.collections import QuadMesh
-from typing import Optional, Union, List, TypeVar
+from typing import Optional, Union, List
 from .cm import cmap_d
 
-T = TypeVar('T', int, float)
-
 
 def _format_axis_label(axis_variable):
     return axis_variable.replace('_', " ").title()
@@ -18,55 +15,62 @@ def _format_axis_label(axis_variable):
 
 def _set_label(
     fg: Union[FacetGrid, QuadMesh, None] = None,
-    frequency: Union[int, float, None] = None,
+    filter_var: str = 'channel',
+    filter_val: Union[str, int, float, None] = None,
     col: Optional[str] = None,
 ):
     props = {'boxstyle': 'square', 'facecolor': 'white', 'alpha': 0.7}
     if isinstance(fg, FacetGrid):
         text_pos = [0.02, 0.06]
         fontsize = 14
-        if col == 'quadrant':
-            if isinstance(frequency, list) or frequency is None:
+        if col == 'beam':
+            if isinstance(filter_val, list) or filter_val is None:
                 for rl in fg.row_labels:
                     if rl is not None:
                         rl.set_text('')
 
                 for idx, cl in enumerate(fg.col_labels):
                     if cl is not None:
-                        cl.set_text(f'Quadrant {fg.col_names[idx]}')
+                        cl.set_text(f'Beam {fg.col_names[idx]}')
 
             text_pos = [0.04, 0.06]
-            fontsize = 13
+            fontsize = 10
 
         for idx, ax in enumerate(fg.axes.flat):
             name_dicts = fg.name_dicts.flatten()
-            if 'frequency' in name_dicts[idx]:
-                freq = name_dicts[idx]['frequency']
-                if col == 'frequency':
+            if filter_var in name_dicts[idx]:
+                chan = name_dicts[idx][filter_var]
+                if col == filter_var:
                     ax.set_title('')
             else:
-                freq = frequency
-                ax.set_title(f'Quadrant {fg.col_names[idx]}')
+                chan = filter_val
+                ax.set_title(f'Beam {fg.col_names[idx]}')
+            axtext = chan
+            if filter_var == 'frequency':
+                axtext = f"{int(chan / 1000)} kHz"
             ax.text(
                 *text_pos,
-                f"{int(freq / 1000)} kHz",
+                axtext,
                 transform=ax.transAxes,
                 fontsize=fontsize,
                 verticalalignment='bottom',
                 bbox=props,
             )
     else:
-        if frequency is None:
+        if filter_val is None:
             raise ValueError(
-                'Frequency value is missing for single echogram plotting.'
+                f'{filter_var.title()} value is missing for single echogram plotting.'
             )
+        axtext = filter_val
+        if filter_var == 'frequency':
+            axtext = f"{int(axtext / 1000)} kHz"
         ax = fg.axes
         ax.text(
             0.02,
             0.04,
-            f"{int(frequency / 1000)} kHz",
+            axtext,
             transform=ax.transAxes,
-            fontsize=16,
+            fontsize=13,
             verticalalignment='bottom',
             bbox=props,
         )
@@ -118,43 +122,68 @@ def _set_plot_defaults(kwargs):
 
 def _plot_echogram(
     ds: xr.Dataset,
-    frequency: Union[int, float, List[T], None] = None,
+    channel: Union[str, List[str], None] = None,
+    frequency: Union[str, List[str], None] = None,
     variable: str = 'backscatter_r',
     xaxis: str = 'ping_time',
-    yaxis: str = 'range',
+    yaxis: str = 'echo_range',
     **kwargs,
 ) -> Union[FacetGrid, QuadMesh]:
     kwargs = _set_plot_defaults(kwargs)
 
     row = None
     col = None
+    filter_var = 'channel'
+    filter_val = None
+    # perform frequency filtering
+    if channel is not None:
+        if 'channel' not in ds.dims:
+            raise ValueError("Channel filtering is not available because channel is not a dimension for your dataset!")
+        ds = ds.sel(channel=channel)
+        filter_val = channel
+    elif frequency is not None:
+        duplicates = False
+        if 'channel' in ds.dims:
+            if len(np.unique(ds.frequency_nominal)) != len(ds.frequency_nominal):
+                duplicates = True
+            ds = ds.where(ds.frequency_nominal.isin(frequency), drop=True)
+        else:
+            if len(np.unique(ds.frequency)) != len(ds.frequency):
+                duplicates = True
+            ds = ds.sel(frequency=frequency)
 
-    if 'quadrant' in ds[variable].dims:
-        col = 'quadrant'
+        if duplicates:
+            raise ValueError("Duplicate frequency found, please use channel for filtering.")
+        filter_val = frequency
+        filter_var = 'frequency'
+
+    if 'backscatter_i' in ds.variables:
+        col = 'beam'
+        kwargs.setdefault('figsize', (15, 5))
         kwargs.update(
             {
-                'figsize': (15, 5),
                 'col_wrap': None,
             }
         )
         filtered_ds = np.abs(ds.backscatter_r + 1j * ds.backscatter_i)
     else:
         filtered_ds = ds[variable]
+        if 'beam' in filtered_ds.dims:
+            filtered_ds = filtered_ds.isel(beam=0).drop('beam')
 
-    # perform frequency filtering
-    if frequency:
-        filtered_ds = filtered_ds.sel(frequency=frequency)
-    else:
-        # if frequency not provided, use all
-        filtered_ds = filtered_ds.sel(frequency=slice(None))
+    if 'channel' in filtered_ds.dims and frequency is not None:
+        filtered_ds = filtered_ds.assign_coords({'frequency': ds.frequency_nominal})
+        filtered_ds = filtered_ds.swap_dims({'channel': 'frequency'})
+        if filtered_ds.frequency.size == 1:
+            filtered_ds = filtered_ds.isel(frequency=0)
 
-    # figure out frequency size
+    # figure out channel/frequency size
     # to determine plotting method
-    if filtered_ds.frequency.size > 1:
+    if filtered_ds[filter_var].size > 1:
         if col is None:
-            col = 'frequency'
+            col = filter_var
         else:
-            row = 'frequency'
+            row = filter_var
 
     filtered_ds[xaxis].attrs = {
         'long_name': filtered_ds[xaxis].attrs.get(
@@ -170,20 +199,19 @@ def _plot_echogram(
     }
 
     plots = []
-    if not filtered_ds.frequency.shape:
+    if not filtered_ds[filter_var].shape:
         if (
             np.any(filtered_ds.isnull()).values == np.array(True)
-            and 'range' in filtered_ds.coords
-            and 'range_bin' in filtered_ds.dims
+            and 'echo_range' in filtered_ds.coords
+            and 'range_sample' in filtered_ds.dims
             and variable in ['backscatter_r', 'Sv']
         ):
             # Handle the nans for echodata and Sv
             filtered_ds = filtered_ds.sel(
-                range_bin=filtered_ds.range_bin.where(
-                    ~filtered_ds.range.isel(ping_time=0).isnull()
-                )
-                .dropna(dim='range_bin')
-                .data
+                ping_time=filtered_ds.echo_range.dropna(dim='ping_time', how='all').ping_time
+            )
+            filtered_ds = filtered_ds.sel(
+                range_sample=filtered_ds.echo_range.dropna(dim='range_sample').range_sample
             )
         plot = filtered_ds.plot.pcolormesh(
             x=xaxis,
@@ -192,14 +220,14 @@ def _plot_echogram(
             row=row,
             **kwargs,
         )
-        _set_label(plot, frequency=frequency, col=col)
+        _set_label(plot, filter_var=filter_var, filter_val=filter_val, col=col)
         plots.append(plot)
     else:
         # Scale plots
-        num_freq = len(filtered_ds.frequency)
-        freq_scaling = (-0.06, -0.16)
+        num_chan = len(filtered_ds[filter_var])
+        chan_scaling = (-0.06, -0.16)
         figsize_scale = tuple(
-            [1 + (scale * num_freq) for scale in freq_scaling]
+            [1 + (scale * num_chan) for scale in chan_scaling]
         )
         new_size = tuple(
             [
@@ -209,24 +237,22 @@ def _plot_echogram(
         )
         kwargs.update({'figsize': new_size})
 
-        for f in filtered_ds.frequency:
-            d = filtered_ds[filtered_ds.frequency == f.values]
+        for f in filtered_ds[filter_var]:
+            d = filtered_ds[filtered_ds[filter_var] == f.values]
             if (
                 np.any(d.isnull()).values == np.array(True)
-                and 'range' in d.coords
-                and 'range_bin' in d.dims
+                and 'echo_range' in d.coords
+                and 'range_sample' in d.dims
                 and variable in ['backscatter_r', 'Sv']
             ):
                 # Handle the nans for echodata and Sv
                 d = d.sel(
-                    range_bin=d.range_bin.where(
-                        ~d.range.sel(frequency=f.values)
-                        .isel(ping_time=0)
-                        .isnull()
-                    )
-                    .dropna(dim='range_bin')
-                    .data
+                    ping_time=d.echo_range.dropna(dim='ping_time', how='all').ping_time
                 )
+                d = d.sel(
+                    range_sample=d.echo_range.dropna(dim='range_sample').range_sample
+                )
+
             plot = d.plot.pcolormesh(
                 x=xaxis,
                 y=yaxis,
@@ -234,6 +260,6 @@ def _plot_echogram(
                 row=row,
                 **kwargs,
             )
-            _set_label(plot, frequency=frequency, col=col)
+            _set_label(plot, filter_var=filter_var, filter_val=filter_val, col=col)
             plots.append(plot)
     return plots
